@@ -4,6 +4,9 @@ class CustomException(Exception):
     """
     A base exception that handles pretty-printing.
     """
+    def __init__(self, msg):
+        self.msg = msg
+
     def __unicode__(self):
         return self.msg
 
@@ -14,15 +17,13 @@ class ColumnIdentifierError(CustomException):
     """
     Exception raised when the user supplies an invalid column identifier.
     """
-    def __init__(self, msg):
-        self.msg = msg
+    pass
 
 class XLSDataError(CustomException):
     """
     Exception raised when there is a problem converting XLS data.
     """
-    def __init__(self, msg):
-        self.msg = msg
+    pass
 
 class CSVTestException(CustomException):
     """
@@ -30,8 +31,7 @@ class CSVTestException(CustomException):
     All must have a line number, the problematic row, and a text explanation.
     """
     def __init__(self, line_number, row, msg):
-        super(CSVTestException, self).__init__()
-        self.msg = msg
+        super(CSVTestException, self).__init__(msg)
         self.line_number = line_number
         self.row = row
         
@@ -47,3 +47,11 @@ class LengthMismatchError(CSVTestException):
     def length(self):
         return len(self.row)
 
+class CSVJSONException(CustomException):
+    """
+    Exception raised when there is a problem converting data to CSV.
+    """
+    pass
+
+class NonUniqueKeyColumnException(CSVJSONException):
+    pass
